( cd usr/lib ; rm -rf xserver )
( cd usr/lib ; ln -sf ../../etc/X11/xserver xserver )
( cd usr/lib ; rm -rf modules )
( cd usr/lib ; ln -sf xorg/modules modules )
( cd usr/bin ; rm -rf inb )
( cd usr/bin ; ln -sf ioport inb )
( cd usr/bin ; rm -rf inw )
( cd usr/bin ; ln -sf ioport inw )
( cd usr/bin ; rm -rf inl )
( cd usr/bin ; ln -sf ioport inl )
( cd usr/bin ; rm -rf outb )
( cd usr/bin ; ln -sf ioport outb )
( cd usr/bin ; rm -rf outw )
( cd usr/bin ; ln -sf ioport outw )
( cd usr/bin ; rm -rf outl )
( cd usr/bin ; ln -sf ioport outl )
( cd usr/bin ; rm -rf X )
( cd usr/bin ; ln -sf Xorg X )
